==> seedsui-react-5.8.44.tgz: package/lib/Map/utils/queryNearby/bmapQueryNearby.js <==
import GeoUtil from "./../../../GeoUtil";

// 测试使用
// import { locale } from 'seedsui-react'
// 内库使用
import locale from "./../../../locale";

// 搜索附近, keyword:搜索关键词
function bmapQueryNearby(_ref) {
  var map = _ref.map,
    keyword = _ref.keyword,
    longitude = _ref.longitude,
    latitude = _ref.latitude,
    radius = _ref.radius;
  if (!longitude || !latitude) {
    return null;
  }
  return new Promise(function (resolve) {
    var bdPoint = GeoUtil.coordtransform([longitude, latitude], 'wgs84', 'bd09');
    bdPoint = new window.BMap.Point(bdPoint[0], bdPoint[1]);
    // 创建本地搜索对象
    var local = new window.BMap.LocalSearch(map, {
      pageCapacity: 20,
      onSearchComplete: function onSearchComplete(results) {
        // 判断状态是否正确
        if (local.getStatus() === window.BMAP_STATUS_SUCCESS) {
          var list = [];
          for (var i = 0; i < results.getCurrentNumPois(); i++) {
            var item = results.getPoi(i);
            if (!item.title && !item.address) continue;
            // Leaflet only support wgs84
            var point = GeoUtil.coordtransform([item.point.lng, item.point.lat], 'bd09', 'wgs84');
            list.push({
              name: item.title,
              address: item.address,
              longitude: point[0],
              latitude: point[1]
            });
          }
          resolve(list);
        } else {
          resolve(locale('查询失败'));
        }
      }
    });

    // 搜索附近
    if (bdPoint && radius) {
      local.searchNearby(keyword, bdPoint, radius);
    }
    // 搜索全部
    else {
      // local.search(keyword) // 此方法只能搜索行政区名称
      local.searchNearby(keyword, bdPoint);
    }
  });
}
export default bmapQueryNearby;

==> seedsui-react-5.8.79.tgz: package/lib/Map/utils/queryNearby/bmapQueryNearby.js <==
// 内库使用
import locale from "./../../../locale";
import GeoUtil from "./../../../GeoUtil";

// 测试使用
// import { locale, GeoUtil } from 'seedsui-react'

// 搜索附近, keyword:搜索关键词
function bmapQueryNearby(_ref) {
  var map = _ref.map,
    keyword = _ref.keyword,
    longitude = _ref.longitude,
    latitude = _ref.latitude,
    radius = _ref.radius;
  if (!(map !== null && map !== void 0 && map.currentMap) || !longitude || !latitude) {
    return null;
  }
  return new Promise(function (resolve) {
    var bdPoint = GeoUtil.coordtransform([longitude, latitude], 'wgs84', 'bd09');
    bdPoint = new window.BMap.Point(bdPoint[0], bdPoint[1]);

    // 定位到当前位置
    map.currentMap.panTo(bdPoint);

    // 创建本地搜索对象
    var local = new window.BMap.LocalSearch(map.currentMap, {
      pageCapacity: 100,
      onSearchComplete: function onSearchComplete(results) {
        // 判断状态是否正确
        if (local.getStatus() === window.BMAP_STATUS_SUCCESS) {
          var list = [];
          for (var i = 0; i < results.getCurrentNumPois(); i++) {
            var item = results.getPoi(i);
            if (!item.title && !item.address) continue;
            // Leaflet only support wgs84
            var point = GeoUtil.coordtransform([item.point.lng, item.point.lat], 'bd09', 'wgs84');
            list.push({
              name: item.title,
              address: item.address,
              longitude: point[0],
              latitude: point[1]
            });
          }
          resolve(list);
        } else {
          resolve(locale('查询失败'));
        }
      }
    });

    // 搜索附近
    if (bdPoint && radius) {
      local.searchNearby(keyword, bdPoint, radius);
    }
    // 搜索全部
    else {
      local.search(keyword);
    }
  });
}
export default bmapQueryNearby;
